@@ -1,19 +1,24 @@
 
 #define HOST_CPU "i386"
 #define HOST_VENDOR "unknown"
-#define HOST_OS "freebsd4.5"
+#define HOST_OS "freebsd4.6"
 #define HOST_OS_NAME "freebsd4"
-#define HOST_OS_VERSION "4.5"
+#define HOST_OS_VERSION "4.6"
 #define HOST_ARCH "i386"
-#define HOST_NAME "localhost"
+#define HOST_NAME "FreeBSD-4.6.fsl.cs.sunysb.edu"
 #define USER_NAME "ezk"
-#define CONFIG_DATE "Tue Feb 26 03:12:24 EST 2002"
+#define CONFIG_DATE "Wed Jun 26 17:14:08 GMT 2002"
 #define PACKAGE_NAME "am-utils"
 #define PACKAGE_VERSION "6.1a6-pre"
 #define PACKAGE_BUGREPORT "amd-dev@am-utils.org"
 #define PACKAGE "am-utils"
 #define VERSION "6.1a6-pre"
 #define DEBUG 1
+#define HAVE_DLFCN_H 1
+#define HOST_HEADER_VERSION "4.6"
+#define YYTEXT_POINTER 1
+#define HAVE_LIBRPCSVC 1
+#define HAVE_ALLOCA 1
 #define STDC_HEADERS 1
 #define HAVE_SYS_TYPES_H 1
 #define HAVE_SYS_STAT_H 1
@@ -23,11 +28,6 @@
 #define HAVE_STRINGS_H 1
 #define HAVE_INTTYPES_H 1
 #define HAVE_UNISTD_H 1
-#define HAVE_DLFCN_H 1
-#define HOST_HEADER_VERSION "4.5"
-#define YYTEXT_POINTER 1
-#define HAVE_LIBRPCSVC 1
-#define HAVE_ALLOCA 1
 #define HAVE_UNISTD_H 1
 #define HAVE_FORK 1
 #define HAVE_VFORK 1
@@ -90,6 +90,7 @@
 #define HAVE_CLNT_SPERRNO 1
 #define HAVE_STRCASECMP 1
 #define HAVE_STRDUP 1
+#define HAVE_STRERROR 1
 #define HAVE_STRSTR 1
 #define HAVE_UALARM 1
 #define HAVE_XDR_ATTRSTAT 1
